# hypermodern-python test
[![Tests](https://github.com/bluemania/hypermodern-python/workflows/Tests/badge.svg)](https://github.com/bluemania/hypermodern-python/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/bluemania/hypermodern-python/branch/master/graph/badge.svg)](https://codecov.io/gh/bluemania/hypermodern-python)

Learning about task automation, linting, testing, static checking, documentation and CI!
